pub fn fuzz_sub_frame_parse(data: &[u8])Expand description
Fuzz header + body (dispatched by Command). Much wider surface than
fuzz_frame_parse because it actually parses the response body for
every command type.
pub fn fuzz_sub_frame_parse(data: &[u8])Fuzz header + body (dispatched by Command). Much wider surface than
fuzz_frame_parse because it actually parses the response body for
every command type.