pub struct SessionSetupResponse {
pub session_flags: SessionFlags,
pub security_buffer: Vec<u8>,
}Expand description
SMB2 SESSION_SETUP response (spec section 2.2.6).
Sent by the server in response to a SESSION_SETUP request. Contains session flags and a security buffer with the server’s auth token.
Fields
session_flags: SessionFlagsFlags indicating additional information about the session.
security_buffer: Vec<u8>Security buffer containing the server’s authentication token.
Implementations
Sourceimpl SessionSetupResponse
impl SessionSetupResponse
pub const STRUCTURE_SIZE: u16 = 9