pub struct IoctlRequest {
pub ctl_code: u32,
pub file_id: FileId,
pub max_input_response: u32,
pub max_output_response: u32,
pub flags: u32,
pub input_data: Vec<u8>,
}Expand description
SMB2 IOCTL Request (MS-SMB2 section 2.2.31).
Sent by the client to issue a device or file system control command. The fixed part is 56 bytes (StructureSize = 57 indicates 1 byte of variable data is included in the fixed size, per SMB2 convention).
Layout:
- StructureSize (2 bytes, must be 57)
- Reserved (2 bytes)
- CtlCode (4 bytes)
- FileId (16 bytes)
- InputOffset (4 bytes)
- InputCount (4 bytes)
- MaxInputResponse (4 bytes)
- OutputOffset (4 bytes)
- OutputCount (4 bytes)
- MaxOutputResponse (4 bytes)
- Flags (4 bytes)
- Reserved2 (4 bytes)
- Buffer (variable, InputCount bytes)
Fields
ctl_code: u32The control code for the operation.
file_id: FileIdThe file handle for the operation.
max_input_response: u32Maximum number of input bytes the server can return.
max_output_response: u32Maximum number of output bytes the server can return.
flags: u32Flags for the request (for example, SMB2_0_IOCTL_IS_FSCTL).
input_data: Vec<u8>Input data buffer.
Implementations
Sourceimpl IoctlRequest
impl IoctlRequest
pub const STRUCTURE_SIZE: u16 = 57